import sys

import pytest

import semeio.hook_implementations.jobs
from ert_shared.plugins.plugin_manager import ErtPluginManager


@pytest.mark.skipif(sys.version_info.major < 3, reason="requires python3")
def test_hook_implementations():
    pm = ErtPluginManager(plugins=[semeio.hook_implementations.jobs])

    expected_jobs = {
        "DESIGN_KW": "semeio/jobs/config_jobs/DESIGN_KW",
        "DESIGN2PARAMS": "semeio/jobs/config_jobs/DESIGN2PARAMS",
        "STEA": "semeio/jobs/config_jobs/STEA",
        "GENDATA_RFT": "semeio/jobs/config_jobs/GENDATA_RFT",
        "PYSCAL": "semeio/jobs/config_jobs/PYSCAL",
    }
    installable_jobs = pm.get_installable_jobs()
    for wf_name, wf_location in expected_jobs.items():
        assert wf_name in installable_jobs
        assert installable_jobs[wf_name].endswith(wf_location)

    assert set(installable_jobs.keys()) == set(expected_jobs.keys())

    expected_workflow_jobs = {
        "CORRELATED_OBSERVATIONS_SCALING": "semeio/jobs/config_workflow_jobs/CORRELATED_OBSERVATIONS_SCALING",
        "SPEARMAN_CORRELATION": "semeio/jobs/config_workflow_jobs/SPEARMAN_CORRELATION",
    }
    installable_workflow_jobs = pm.get_installable_workflow_jobs()
    for wf_name, wf_location in expected_workflow_jobs.items():
        assert wf_name in installable_workflow_jobs
        assert installable_workflow_jobs[wf_name].endswith(wf_location)

    assert set(installable_workflow_jobs.keys()) == set(expected_workflow_jobs.keys())



import itertools
import argparse
import pytest

from semeio.jobs.rft.trajectory import TrajectoryPoint, Trajectory
from semeio.jobs.rft.zonemap import ZoneMap


@pytest.mark.parametrize(
    "line, expected_zone", [("0 1 2.2 3", None), ("0 1 2.2 3 zone", "zone"),]
)
def test_load_from_line(line, expected_zone):
    point = TrajectoryPoint(*Trajectory.parse_trajectory_line(line))
    assert point.utm_x == 0
    assert point.utm_y == 1
    assert point.measured_depth == 2.2
    assert point.true_vertical_depth == 3
    assert point.zone == expected_zone


@pytest.mark.parametrize(
    "line, expected_error",
    [
        ("1", "Trajectory data file not on correct format"),
        ("a b c", "Trajectory data file not on correct format"),
        ("a b c d e", "Error: Failed to extract data from line"),
    ],
)
def test_invalid_load_from_line(line, expected_error):
    with pytest.raises(argparse.ArgumentTypeError) as err_context:
        TrajectoryPoint(*Trajectory.parse_trajectory_line(line))
    assert expected_error in err_context.value.args[0]


@pytest.mark.parametrize(
    "k_value, expected_validation", [(1, True), (3, False), (4, False)]
)
def test_validate_zone(k_value, expected_validation):
    zones_at_k_value = {1: ["Zone1", "Zone2"], 3: ["Zone3"]}
    zone_map = ZoneMap(zones_at_k_value)

    point = TrajectoryPoint(0, 1, 2, 3, "Zone1")
    point.set_ijk([0, 0, k_value])

    assert not point.valid_zone
    point.validate_zone(zone_map)

    assert point.valid_zone == expected_validation


def test_validate_non_existing_zone():
    zones_at_k_value = {1: ["Zone1", "Zone2"], 3: ["Zone3"]}
    zone_map = ZoneMap(zones_at_k_value)

    point = TrajectoryPoint(0, 1, 2, 3, "non existing")
    point.set_ijk((0, 0, 1))
    point.validate_zone(zone_map)
    assert not point.valid_zone


ijks = [None, (0, 0, 0)]
pressures = [None, 1]
validations = [False, True]


@pytest.mark.parametrize(
    "ijk, pressure, validation", itertools.product(ijks, pressures, validations)
)
def test_is_active(ijk, pressure, validation):

    point = TrajectoryPoint(0, 1, 2, 3, "Zone1")
    point.set_ijk(ijk)
    point.pressure = pressure
    point.valid_zone = validation
    assert all([ijk, pressure, validation]) == point.is_active()

    assert 1 if all([ijk, pressure, validation]) else -1 == point.get_pressure()


@pytest.fixture()
def initdir(tmpdir):
    tmpdir.chdir()
    valid_data = """
0 1 2.2 3
4 5 6 7 zone
"""
    tmpdir.join("valid_trajectories.txt").write(valid_data)
    comment = "-- this is a comment"
    valid_data = comment + "\n" + valid_data + comment
    tmpdir.join("valid_trajectories_with_comments.txt").write(valid_data)


@pytest.mark.parametrize(
    "fname", ["valid_trajectories.txt", "valid_trajectories_with_comments.txt"]
)
def test_load(initdir, fname):
    expected_utmxs = [0, 4]
    trajectory = Trajectory.load_from_file(fname)

    for expected_utmx, trajectorypoint in zip(
        expected_utmxs, trajectory.trajectory_points
    ):
        assert trajectorypoint.utm_x == expected_utmx


def test_non_existing_file():

    with pytest.raises(argparse.ArgumentTypeError) as err_context:
        Trajectory.load_from_file("non_existing")

    assert (
        "Warning: Trajectory file non_existing not found!" == err_context.value.args[0]
    )



from copy import deepcopy

import pytest
import configsuite

from semeio.jobs.correlated_observations_scaling.job_config import (
    _expand_input,
    _min_value,
    _to_int_list,
    build_schema,
)


@pytest.mark.parametrize(
    "valid_input",
    [
        "0,1,2-5",
        [0, 1, "2-5"],
        [0, 1, 2, 3, 4, 5],
        [0, 1, "2-3", "4-5"],
        "0-5",
        "0-1,2,3-5",
        ["0,1,2-5"],
    ],
)
def test_to_int_list(valid_input):
    expected_result = list(range(6))
    assert _to_int_list(valid_input) == expected_result


@pytest.mark.parametrize(
    "test_input,expected_result", [(-1, False), (0, True), (1, True)]
)
def test_min_value(test_input, expected_result):
    assert _min_value(test_input).__bool__() == expected_result


def test_expand_input_no_modification():
    expected_result = {
        "UPDATE_KEYS": {"keys": [{"key": "key_4"}, {"key": "key_5"}, {"key": "key_6"}]},
        "CALCULATE_KEYS": {
            "keys": [{"key": "key_1"}, {"key": "key_2"}, {"key": "key_3"}],
            "threshold": 1.0,
        },
    }

    assert _expand_input(deepcopy(expected_result)) == expected_result


def test_expand_input_modification():
    keys = [{"key": "key_1"}, {"key": "key_2"}, {"key": "key_3"}]
    test_input = {"CALCULATE_KEYS": {"keys": keys, "threshold": 1.0}}

    expected_results = deepcopy(test_input)
    expected_results["UPDATE_KEYS"] = {"keys": keys}

    assert _expand_input(test_input) == expected_results


def test_config_setup():

    valid_config_data = {
        "CALCULATE_KEYS": {"keys": [{"key": "first_key"}, {"key": "second_key"}]}
    }

    schema = build_schema()
    config = configsuite.ConfigSuite(valid_config_data, schema)
    assert config.valid

    valid_config_data = {
        "CALCULATE_KEYS": {"keys": [{"key": "first_key"}, {"key": "second_key"}]},
        "UPDATE_KEYS": {"keys": [{"index": [1, 2, 3], "key": "first_key"}]},
    }

    schema = build_schema()
    config = configsuite.ConfigSuite(valid_config_data, schema)
    assert config.valid

    invalid_too_short_index_list = {
        "UPDATE_KEYS": {"keys": [{"index": "1", "key": ["a_key"]}]}
    }

    config = configsuite.ConfigSuite(invalid_too_short_index_list, schema)
    assert not config.valid

    invalid_missing_required_keyword = {
        "CALCULATE_KEYS": {"keys": [{"key": "a_key"}]},
        "UPDATE_KEYS": {"index": "1-5"},
    }

    config = configsuite.ConfigSuite(invalid_missing_required_keyword, schema)
    assert not config.valid

    invalid_negative_index = {
        "CALCULATE_KEYS": {"keys": [{"key": "first_key"}, {"key": "second_key"}]},
        "UPDATE_KEYS": {"keys": [{"index": [-1, 2, 3], "key": "first_key"}]},
    }

    schema = build_schema()
    config = configsuite.ConfigSuite(invalid_negative_index, schema)
    assert not config.valid


def test_valid_configuration():
    valid_config_data = {
        "CALCULATE_KEYS": {"keys": [{"key": "POLY_OBS"}]},
        "UPDATE_KEYS": {"keys": [{"key": "POLY_OBS"}]},
    }

    schema = build_schema()
    config = configsuite.ConfigSuite(valid_config_data, schema)

    assert config.valid



# -*- coding: utf-8 -*-
import os
from copy import deepcopy

import six

import configsuite
from configsuite import MetaKeys as MK
from configsuite import types


@configsuite.validator_msg("Minimum length of index list must be > 1 for PCA")
def _min_length(value):
    return len(value) > 1


@configsuite.validator_msg("Minimum value of index must be >= 0")
def _min_value(value):
    return value >= 0


_num_convert_msg = "Will go through the input and try to convert to list of int"


@configsuite.transformation_msg(_num_convert_msg)
def _to_int_list(value):
    value = deepcopy(value)
    if isinstance(value, six.integer_types):
        return [value]
    elif isinstance(value, (list, tuple)):
        value = ",".join([str(x) for x in value])
    return _realize_list(value)


@configsuite.transformation_msg("Convert ranges and singeltons into list")
def _realize_list(input_string):
    """If input_string is not a string, input_string will be returned. If input_string
    is a string it is assumed to contain comma separated elements. Each element is
    assumed to be either a singelton or a range. A singleton is a single number,
    i.e.  7 or 14. A range is a lower and upper element of the range separated by a
    single '-'. When provided with a string we will either return a list containing the
    union of all the singeltons and the ranges, or raise a TypeError or ValueError if
    it fails in the process. _realize_list('1,2,4-7,14-15') -> [1, 2, 4, 5, 6, 7, 14, 15]
    """
    real_list = []
    for elem in input_string.split(","):
        bounds = elem.split("-")
        if len(bounds) == 1:
            if "-" in elem:
                raise ValueError("Did not expect '-' in singleton")
            real_list.append(int(elem))
        elif len(bounds) == 2:
            if elem.count("-") != 1:
                raise ValueError("Did expect single '-' in range")
            lower_bound = int(bounds[0])
            upper_bound = int(bounds[1]) + 1

            if lower_bound > upper_bound:
                err_msg = "Lower bound of range expected to be smaller then upper bound"
                raise ValueError(err_msg)

            real_list += range(lower_bound, upper_bound)
        else:
            raise ValueError("Expected at most one '-' in an element")

    return real_list


_num_convert_msg = "Create UPDATE_KEYS from CALCULATE_KEYS as it was not specified"


@configsuite.transformation_msg(_num_convert_msg)
def _expand_input(input_value):
    expanded_values = deepcopy(input_value)
    if "CALCULATE_KEYS" in expanded_values and "UPDATE_KEYS" not in expanded_values:
        expanded_values.update(
            {"UPDATE_KEYS": {"keys": expanded_values["CALCULATE_KEYS"]["keys"]}}
        )
    return expanded_values


@configsuite.validator_msg("Threshold must be higher than 0 and lower than 1")
def _min_max_value(value):
    return 0.0 < value < 1.0


def build_schema():
    return {
        MK.Type: types.NamedDict,
        MK.Description: "Keys and index lists from all scaled keys",
        MK.LayerTransformation: _expand_input,
        MK.Content: {
            "CALCULATE_KEYS": {
                MK.Required: True,
                MK.Type: types.NamedDict,
                MK.Content: {
                    "keys": {
                        MK.Required: True,
                        MK.Type: types.List,
                        MK.Content: {
                            MK.Item: {
                                MK.Type: types.NamedDict,
                                MK.Content: {
                                    "key": {MK.Required: True, MK.Type: types.String},
                                    "index": {
                                        MK.Required: False,
                                        MK.Type: types.List,
                                        MK.LayerTransformation: _to_int_list,
                                        MK.Content: {
                                            MK.Item: {
                                                MK.Type: types.Integer,
                                                MK.ElementValidators: (_min_value,),
                                            }
                                        },
                                    },
                                },
                            }
                        },
                    },
                    "threshold": {
                        MK.Required: False,
                        MK.Type: types.Number,
                        MK.ElementValidators: (_min_max_value,),
                    },
                    "std_cutoff": {MK.Required: False, MK.Type: types.Number},
                    "alpha": {MK.Required: False, MK.Type: types.Number},
                },
            },
            "UPDATE_KEYS": {
                MK.Required: False,
                MK.Type: types.NamedDict,
                MK.Content: {
                    "keys": {
                        MK.Required: False,
                        MK.Type: types.List,
                        MK.Content: {
                            MK.Item: {
                                MK.Type: types.NamedDict,
                                MK.Content: {
                                    "key": {MK.Required: True, MK.Type: types.String},
                                    "index": {
                                        MK.Required: False,
                                        MK.Type: types.List,
                                        MK.LayerTransformation: _to_int_list,
                                        MK.Content: {
                                            MK.Item: {
                                                MK.Type: types.Integer,
                                                MK.ElementValidators: (_min_value,),
                                            }
                                        },
                                    },
                                },
                            }
                        },
                    }
                },
            },
        },
    }


def get_default_values():
    default_values = {
        "CALCULATE_KEYS": {"threshold": 0.95, "std_cutoff": 1e-6, "alpha": 3.0},
        "UPDATE_KEYS": {},
    }
    return default_values



import os
from distutils.dir_util import copy_tree
import numpy
import pytest

from semeio.jobs.scripts.gendata_rft import main_entry_point

ECL_BASE = os.path.join(
    os.path.dirname(os.path.abspath(__file__)), "data/norne/NORNE_ATW2013"
)
EXPECTED_RESULTS_PATH = os.path.join(
    os.path.dirname(os.path.abspath(__file__)), "data/norne/expected_result"
)

MOCK_DATA_CONTENT = {
    "RFT_B-1AH_0_active": [1] * 5,
    "RFT_B-4AH_0_active": [1] * 7 + [0] * 1 + [1] * 21,
    "RFT_B-4H_0_active": [1] * 20,
    "RFT_C-1H_0_active": [1] * 21,
    "RFT_C-3H_0_active": [1] * 21,
    "RFT_C-4AH_0_active": [1] * 15,
}


def _assert_almost_equal_line_by_line(file1, file2):
    with open(file1) as fh:
        file1_content = fh.readlines()

    with open(file2) as fh:
        file2_content = fh.readlines()

    assert len(file1_content) == len(file2_content)

    for line1, line2 in zip(file1_content, file2_content):
        try:
            line1, line2 = float(line1), float(line2)
        except ValueError:
            continue
        numpy.testing.assert_almost_equal(line1, line2, decimal=7)


def _generate_mock_data(write_directory):
    for fname, content in MOCK_DATA_CONTENT.items():
        with open(os.path.join(write_directory, fname), "w+") as fh:
            fh.write("\n".join([str(c) for c in content]))


@pytest.fixture
def input_data(tmpdir):
    data_dir = os.path.join(
        os.path.dirname(os.path.abspath(__file__)), "data/norne/gendata_rft_input_files"
    )
    copy_tree(data_dir, tmpdir.strpath)

    cwd = os.getcwd()
    tmpdir.chdir()

    expected_results_dir = os.path.join(tmpdir.strpath, "expected_results")
    os.mkdir(expected_results_dir)

    copy_tree(EXPECTED_RESULTS_PATH, expected_results_dir)
    _generate_mock_data(expected_results_dir)

    try:
        yield

    finally:
        os.chdir(cwd)


def test_gendata_rft_entry_point(tmpdir, input_data):

    arguments = [
        "-e",
        ECL_BASE,
        "-w",
        "well_and_time.txt",
        "-t",
        tmpdir.strpath,
        "-z",
        "zonemap.txt",
    ]

    main_entry_point(arguments)
    expected_results_dir = os.path.join(tmpdir.strpath, "expected_results")

    expected_files = [
        os.path.join(EXPECTED_RESULTS_PATH, fname)
        for fname in os.listdir(EXPECTED_RESULTS_PATH)
    ]

    expected_files.extend(
        [
            os.path.join(expected_results_dir, fname)
            for fname in os.listdir(expected_results_dir)
        ]
    )

    for expected_file in expected_files:
        filename = os.path.basename(expected_file)
        assert filename in os.listdir(tmpdir.strpath)

        if not filename.endswith("inactive_info"):
            result_file = os.path.join(tmpdir.strpath, filename)

            _assert_almost_equal_line_by_line(expected_file, result_file)


def test_gendata_inactive_info_point_not_in_grid(tmpdir, input_data):

    with open("B-1AH.txt", "a+") as fh:
        fh.write("0 1 2 3\n")

    with open("well_and_time.txt", "w+") as fh:
        fh.write("B-1AH 1 12 2005 0\n")

    arguments = [
        "-e",
        ECL_BASE,
        "-w",
        "well_and_time.txt",
        "-t",
        tmpdir.strpath,
        "-z",
        "zonemap.txt",
    ]
    main_entry_point(arguments)

    with open("RFT_B-1AH_0_inactive_info") as fh:
        result = fh.read()
        assert result.startswith("TRAJECTORY_POINT_NOT_IN_GRID")


def test_gendata_inactive_info_zone_mismatch(tmpdir, input_data):

    with open("well_and_time.txt", "w+") as fh:
        fh.write("B-1AH 1 12 2005 0\n")

    with open(os.path.join(tmpdir.strpath, "B-1AH.txt"), "r+") as fh:
        lines = fh.readlines()

    line = lines[-1].rsplit(" ", 1)[0]
    line = line + " last_zone"

    with open("B-1AH.txt", "w+") as fh:
        fh.write(line)

    arguments = [
        "-e",
        ECL_BASE,
        "-w",
        "well_and_time.txt",
        "-t",
        tmpdir.strpath,
        "-z",
        "zonemap.txt",
    ]
    main_entry_point(arguments)

    with open("RFT_B-1AH_0_inactive_info") as fh:
        result = fh.read()
        assert result.startswith("ZONE_MISMATCH")


def test_gendata_inactive_info_not_in_rft(tmpdir, input_data):

    with open("well_and_time.txt", "w+") as fh:
        fh.write("B-1AH 1 12 2005 0\n")

    with open(os.path.join(tmpdir.strpath, "B-1AH.txt"), "r+") as fh:
        lines = fh.readlines()

    line = lines[-1].rsplit(" ", 3)[0]
    line += " 2700 2700"

    with open("B-1AH.txt", "w+") as fh:
        fh.write(line)

    arguments = [
        "-e",
        ECL_BASE,
        "-w",
        "well_and_time.txt",
        "-t",
        tmpdir.strpath,
        "-z",
        "zonemap.txt",
    ]
    main_entry_point(arguments)

    with open("RFT_B-1AH_0_inactive_info") as fh:
        result = fh.read()
        assert result.startswith("TRAJECTORY_POINT_NOT_IN_RFT")


def test_gendata_inactive_info_zone_missing_value(tmpdir, input_data):

    with open("well_and_time.txt", "w+") as fh:
        fh.write("B-1AH 1 12 2005 0\n")

    with open("zonemap.txt", "w+") as fh:
        fh.write("1 zone1\n")

    arguments = [
        "-e",
        ECL_BASE,
        "-w",
        "well_and_time.txt",
        "-t",
        tmpdir.strpath,
        "-z",
        "zonemap.txt",
    ]

    main_entry_point(arguments)

    with open("RFT_B-1AH_0_inactive_info") as fh:
        result = fh.read()
        assert result.startswith("ZONEMAP_MISSING_VALUE")



#!/usr/bin/env python
#
import argparse
import logging
import os
import sys

from semeio import valid_file
from semeio.jobs.design2params import design2params

description = """
Reads a design matrix in XLSX-format and:
 * Converts specified worksheet to txt-format and puts designmatrix.txt in RUNPATH
 * Fetches values belonging to given ERT realization and *appends*
   key-value pairs to parameters.txt
 * Creates designparameters.txt which only contains variables taken from the design matrix, this
   can be given to CUSTOM_KW
Requires a matrix with column header as strings in topmost row in Excel.
Row 2 in Excel must then correspond with the data you want for 'realization 0'
Column 1 in Excel should contain the realization number, and will be ignored by this script.
You must run this script as a FORWARD_MODEL from your ERT config, before
you run DESIGN_KW.
"""


def create_parser():
    parser = argparse.ArgumentParser(description=description)

    parser.add_argument(
        "realization", type=int, help="Which realization",
    )

    parser.add_argument(
        "xlsfilename", type=valid_file, help="Path to design-matrix (xlsx file)",
    )

    parser.add_argument(
        "designsheetname", type=str, help="Design sheet name",
    )

    parser.add_argument(
        "defaultssheetname",
        type=str,
        nargs="?",
        help="Defaults sheet name",
        default=None,
    )

    parser.add_argument(
        "--parametersfilename",
        "-p",
        required=False,
        default=design2params._PARAMETERS_TXT,
        type=str,
    )

    parser.add_argument(
        "--log-level",
        "-l",
        required=False,
        default="WARNING",
        type=logging.getLevelName,
    )

    return parser


def main(args):
    parser = create_parser()
    parsed_args = parser.parse_args(args)
    design2params.run(
        realization=parsed_args.realization,
        xlsfilename=parsed_args.xlsfilename,
        designsheetname=parsed_args.designsheetname,
        defaultssheetname=parsed_args.defaultssheetname,
        parametersfilename=parsed_args.parametersfilename,
        log_level=parsed_args.log_level,
    )


if __name__ == "__main__":
    main(sys.argv[1:])



import os
import shutil
import sys

import pytest

import semeio.jobs.scripts.spearman_correlation as sc
from res.enkf import EnKFMain, ResConfig
from semeio.jobs.correlated_observations_scaling.exceptions import EmptyDatasetException
from tests.jobs.correlated_observations_scaling.conftest import TEST_DATA_DIR

if sys.version_info >= (3, 3):
    from unittest.mock import Mock
else:
    from mock import Mock


@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
@pytest.mark.usefixtures("setup_tmpdir")
def test_main_entry_point_gen_data(monkeypatch):
    run_mock = Mock()
    scal_job = Mock(return_value=Mock(run=run_mock))
    monkeypatch.setattr(sc, "CorrelatedObservationsScalingJob", scal_job)

    test_data_dir = os.path.join(TEST_DATA_DIR, "local", "snake_oil")

    shutil.copytree(test_data_dir, "test_data")
    os.chdir(os.path.join("test_data"))

    res_config = ResConfig("snake_oil.ert")
    ert = EnKFMain(res_config)
    sc.SpearmanCorrelationJob(ert).run(*["-t", "1.0"])

    # call_args represents the clusters, we expect the snake_oil
    # observations to generate this amount of them
    # call_args is a call object, which itself is a tuple of args and kwargs.
    # In this case, we want args, and the first element of the arguments, which
    # again is a tuple containing the configuration which is a list of configs.
    assert len(run_mock.call_args[0][0]) == 47, "wrong number of clusters"


@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
@pytest.mark.usefixtures("setup_tmpdir")
def test_scaling():
    test_data_dir = os.path.join(TEST_DATA_DIR, "local", "snake_oil")

    shutil.copytree(test_data_dir, "test_data")
    os.chdir(os.path.join("test_data"))

    res_config = ResConfig("snake_oil.ert")
    ert = EnKFMain(res_config)

    sc.SpearmanCorrelationJob(ert).run(*["-t", "1.0"])

    # assert that this arbitrarily chosen cluster gets scaled as expected
    obs = ert.getObservations()["FOPR"]
    for index in [13, 14, 15, 16, 17, 18, 19, 20]:
        assert obs.getNode(index).getStdScaling() == 2.8284271247461903


@pytest.mark.skipif(TEST_DATA_DIR is None, reason="no libres test-data")
@pytest.mark.usefixtures("setup_tmpdir")
def test_skip_clusters_yielding_empty_data_matrixes(monkeypatch):
    def raising_scaling_job(data):
        if data == {"CALCULATE_KEYS": {"keys": [{"index": [88, 89], "key": "FOPR"}]}}:
            raise EmptyDatasetException("foo")

    scaling_mock = Mock(return_value=Mock(**{"run.side_effect": raising_scaling_job}))
    monkeypatch.setattr(sc, "CorrelatedObservationsScalingJob", scaling_mock)

    test_data_dir = os.path.join(TEST_DATA_DIR, "local", "snake_oil")

    shutil.copytree(test_data_dir, "test_data")
    os.chdir(os.path.join("test_data"))

    res_config = ResConfig("snake_oil.ert")
    ert = EnKFMain(res_config)
    job = sc.SpearmanCorrelationJob(ert)

    try:
        job.run(*["-t", "1.0"])
    except EmptyDatasetException:
        pytest.fail("EmptyDatasetException was not handled by SC job")



import logging
import os
from distutils.dir_util import copy_tree

import pytest

from semeio.jobs.design_kw import design_kw


@pytest.fixture
def input_data(tmpdir):
    data_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
    copy_tree(data_dir, tmpdir.strpath)

    cwd = os.getcwd()
    tmpdir.chdir()

    yield

    os.chdir(cwd)


def test_extract_key_value_ok():
    data = ["key1 14", "key2 24", "key3 34"]
    assert design_kw.extract_key_value(data) == {
        "key1": "14",
        "key2": "24",
        "key3": "34",
    }


def test_extract_key_value_dup_key():
    data = ["key1 14", "key2 24", "key1 34"]
    with pytest.raises(SystemExit):
        design_kw.extract_key_value(data)


def test_is_comment():
    line = "# this is a std pattern comment"
    assert design_kw.is_comment(line)

    line = "-- this is a ecl comment"
    assert design_kw.is_comment(line)

    line = "  ECLIPSE_INIT_DATE: [2000-01-01]"
    assert not design_kw.is_comment(line)


def test_unmatched_templates():
    line = "  ECLIPSE_INIT_DATE: [2000-01-01]"
    assert not design_kw.unmatched_templates(line)

    line = "  ECLIPSE_INIT_DATE: <DATE>"
    assert design_kw.unmatched_templates(line) == ["<DATE>"]


def test_is_perl():
    file_name = "filename.yml"
    template = ["perl", "  ECLIPSE_INIT_DATE: <DATE>"]
    assert design_kw.is_perl(file_name, template)

    file_name = "filename.pl"
    template = ["perl", "  ECLIPSE_INIT_DATE: <DATE>"]
    assert design_kw.is_perl(file_name, template)

    file_name = "filename.pl"
    template = ["  ECLIPSE_INIT_DATE: <DATE>"]
    assert design_kw.is_perl(file_name, template)

    file_name = "filename.yml"
    template = ["  ECLIPSE_INIT_DATE: <DATE>"]
    assert not design_kw.is_perl(file_name, template)


def test_run(input_data):
    reference_filename = "template.yml.reference"
    template_filename = "template.yml.tmpl"
    result_filename = "template.yml"

    design_kw.run(template_filename, result_filename, log_level=logging.DEBUG)

    with open(result_filename, "r") as result_file:
        result = result_file.read()

    with open(reference_filename, "r") as reference_file:
        reference = reference_file.read()

    with open(design_kw._STATUS_FILE_NAME, "r") as status_file:
        status = status_file.read()

    assert result == reference
    assert status == "DESIGN_KW OK\n"


def test_run_unmatched(input_data):
    template_filename = "template_unmatched.yml.tmpl"
    result_filename = "template.yml"
    design_kw.run(
        template_file_name=template_filename,
        result_file_name=result_filename,
        log_level=logging.DEBUG,
        parameters_file_name="parameters.txt",
    )

    assert not os.path.isfile(design_kw._STATUS_FILE_NAME)


def test_run_duplicate_keys(input_data):
    template_filename = "template.yml.tmpl"
    result_filename = "template.yml"
    with pytest.raises(SystemExit):
        design_kw.run(
            template_file_name=template_filename,
            result_file_name=result_filename,
            log_level=logging.DEBUG,
            parameters_file_name="parameters_w_duplicates.txt",
        )

    assert not os.path.isfile(design_kw._STATUS_FILE_NAME)



import logging

logger = logging.getLogger(__name__)


def _write_points(points, fname):
    with open(fname, "w+") as fh:
        fh.write("\n".join([str(p.get_pressure()) for p in points]))
    logger.info("Forward model script gendata_rft.py: Wrote file {}".format(fname))

    with open(fname + "_active", "w+") as fh:
        fh.write("\n".join([str(int(p.is_active())) for p in points]))


def _write_inactive_info(points, fname, zonemap=None):
    with open(fname + "_inactive_info", "w+") as fh:
        fh.write(
            "\n".join([p.inactive_info(zonemap) for p in points if not p.is_active()])
        )


def _populate_trajectory_points(
    well, date, trajectory_points, ecl_grid, ecl_rft, zonemap=None
):
    try:
        rft = ecl_rft.get(well, date)
    except KeyError:
        logger.error(
            "Forward model script gendata_rft.py: No RFT data written for well ({}) and date ({})".format(
                well, date
            )
        )
        return []

    for point in trajectory_points:
        point.set_ijk(
            ecl_grid.find_cell(point.utm_x, point.utm_y, point.true_vertical_depth)
        )
        point.update_pressure_from_rft(rft)
        point.validate_zone(zonemap)

    return trajectory_points


def run(well_times, trajectories, ecl_grid, ecl_rft, zonemap=None):

    for well, time, report_step in well_times:
        logger.debug("Collecting RFT for well: {} at date: {}".format(well, time))

        trajectory_points = _populate_trajectory_points(
            well, time, trajectories[well], ecl_grid, ecl_rft, zonemap
        )
        if trajectory_points:
            fname = "RFT_{}_{}".format(well, report_step)

            _write_points(trajectory_points, fname)
            _write_inactive_info(trajectory_points, fname, zonemap)

    with open("GENDATA_RFT.OK", "w") as fh:
        fh.write("GENDATA RFT completed OK")



import collections

import yaml

from ert_data.measured import MeasuredData
from ert_shared.libres_facade import LibresFacade
from res.enkf import ErtScript
from semeio.jobs.correlated_observations_scaling.job import ScalingJob
from semeio.jobs.correlated_observations_scaling.obs_utils import keys_with_data


class CorrelatedObservationsScalingJob(ErtScript):
    def run(self, job_config):
        facade = LibresFacade(self.ert())
        user_config = load_yaml(job_config)
        user_config = _insert_default_group(user_config)

        obs = facade.get_observations()
        obs_keys = [facade.get_observation_key(nr) for nr, _ in enumerate(obs)]
        obs_with_data = keys_with_data(
            obs, obs_keys, facade.get_ensemble_size(), facade.get_current_fs(),
        )

        for config in user_config:
            job = ScalingJob(obs_keys, obs, obs_with_data, config)
            measured_data = MeasuredData(
                facade, job.get_calc_keys(), job.get_index_lists()
            )
            job.scale(measured_data)


def load_yaml(job_config):
    # Allow job_config to be both list and dict.
    if isinstance(job_config, dict) or isinstance(job_config, list):
        return job_config

    with open(job_config, "r") as fin:
        return yaml.safe_load(fin)


def _insert_default_group(value):
    if isinstance(value, collections.Mapping):
        return [value]
    return value



# -*- coding: utf-8 -*-
import configsuite
from semeio.jobs.correlated_observations_scaling import job_config
from semeio.jobs.correlated_observations_scaling.exceptions import ValidationError
from semeio.jobs.correlated_observations_scaling.obs_utils import (
    create_active_lists,
    find_and_expand_wildcards,
)
from semeio.jobs.correlated_observations_scaling.scaled_matrix import DataMatrix
from semeio.jobs.correlated_observations_scaling.validator import has_keys, is_subset


class ScalingJob(object):
    def __init__(self, obs_keys, obs, obs_with_data, user_config_dict):
        """Creates a ScalingJob instance with the given obs_keys, obs,
        obs_with_data and user_config_dict."""
        self._obs = obs
        self._obs_with_data = obs_with_data
        self._obs_keys = obs_keys
        self._config = self._setup_configuration(user_config_dict)
        self._validate()

    def scale(self, measured_data):
        """
        Collects data, performs scaling and applies scaling, assumes validated input.
        """
        config = self._config.snapshot

        measured_data.remove_failed_realizations()
        measured_data.remove_inactive_observations()
        measured_data.filter_ensemble_mean_obs(config.CALCULATE_KEYS.alpha)
        measured_data.filter_ensemble_std(config.CALCULATE_KEYS.std_cutoff)

        matrix = DataMatrix(measured_data.data)
        matrix.std_normalization(inplace=True)

        scale_factor = matrix.get_scaling_factor(config.CALCULATE_KEYS)

        update_data = create_active_lists(self._obs, config.UPDATE_KEYS.keys)
        self._update_scaling(self._obs, scale_factor, update_data)

    def _validate(self):
        """
        Validates the job. If invalid, raises an ValidationError.
        """
        errors = [] if self._config.valid else self._config.errors
        calc_keys = self.get_calc_keys()
        application_keys = [
            entry.key for entry in self._config.snapshot.UPDATE_KEYS.keys
        ]

        errors.extend(is_subset(calc_keys, application_keys))
        errors.extend(
            has_keys(self._obs_keys, calc_keys, "Key: {} has no observations")
        )
        errors.extend(has_keys(self._obs_with_data, calc_keys, "Key: {} has no data"))
        if len(errors) > 0:
            raise ValidationError("Invalid job", errors)

    def get_calc_keys(self):
        return [event.key for event in self._config.snapshot.CALCULATE_KEYS.keys]

    def get_index_lists(self):
        return [event.index for event in self._config.snapshot.CALCULATE_KEYS.keys]

    def _setup_configuration(self, config_data):
        """
        Creates a ConfigSuite instance and inserts default values
        """
        schema = job_config.build_schema()
        config_dict = find_and_expand_wildcards(self._obs_keys, config_data)
        default_layer = job_config.get_default_values()
        config = configsuite.ConfigSuite(config_dict, schema, layers=(default_layer,))
        return config

    def _update_scaling(self, obs, scale_factor, events):
        """
        Applies the scaling factor to the user specified index, SUMMARY_OBS needs to be treated differently
        as it only has one data point per node, compared with other observation types which have multiple
        data points per node.
        """
        for event in events:
            obs_vector = obs[event.key]
            for index, obs_node in enumerate(obs_vector):
                if obs_vector.getImplementationType().name == "SUMMARY_OBS":
                    index_list = (
                        event.index
                        if event.index is not None
                        else range(len(obs_vector))
                    )
                    if index in index_list:
                        obs_node.set_std_scaling(scale_factor)
                elif obs_vector.getImplementationType().name != "SUMMARY_OBS":
                    obs_node.updateStdScaling(scale_factor, event.active_list)
        print(
            "Keys: {} scaled with scaling factor: {}".format(
                [event.key for event in events], scale_factor
            )
        )



#!/usr/bin/env python

import stea
import argparse
from semeio import valid_file


def _get_args_parser():
    description = (
        "STEA is a powerful economic analysis tool used for complex economic"
        "analysis and portfolio optimization. STEA helps you analyze single"
        "projects, large and small portfolios and complex decision trees."
        "As output, for each of the entries in the result section of the"
        "yaml config file, STEA will create result files"
        "ex: Res1_0, Res2_0, .. Res#_0"
    )
    parser = argparse.ArgumentParser(description=description)

    parser.add_argument(
        "-c",
        "--config",
        help="STEA config file, yaml format required",
        type=valid_file,
    )
    return parser


def main_entry_point(args=None):
    parser = _get_args_parser()
    options = parser.parse_args(args)
    stea_input = stea.SteaInput([options.config])
    res = stea.calculate(stea_input)
    for res, value in res.results(stea.SteaKeys.CORPORATE).items():
        with open("{}_0".format(res), "w") as ofh:
            ofh.write("{}\n".format(value))


if __name__ == "__main__":
    main_entry_point()



import filecmp
import logging
import os
from distutils.dir_util import copy_tree

import pytest

from semeio.jobs.design2params import design2params


@pytest.fixture
def input_data(tmpdir):
    data_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
    copy_tree(data_dir, tmpdir.strpath)

    cwd = os.getcwd()
    tmpdir.chdir()

    yield

    os.chdir(cwd)


@pytest.mark.usefixtures("input_data")
@pytest.mark.parametrize(
    "test_file, expected_file",
    [
        (design2params._PARAMETERS_TXT, "refparameters.txt"),
        (design2params._DESIGN_MATRIX_TXT, "refdesignmatrix.txt"),
        (design2params._DESIGN_PARAMETERS_TXT, "refdesignparameters.txt"),
    ],
)
def test_run(test_file, expected_file):
    design2params.run(
        1,
        "design_matrix.xlsx",
        "DesignSheet01",
        "DefaultValues",
        design2params._PARAMETERS_TXT,
        log_level=logging.DEBUG,
    )

    assert filecmp.cmp(test_file, expected_file)

    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
        status = status_file.read()
        assert status == "OK\n"


@pytest.mark.usefixtures("input_data")
@pytest.mark.parametrize(
    "test_file, expected_file",
    [
        ("new_parameters.txt", "refparameters_when_missing.txt"),
        (design2params._DESIGN_MATRIX_TXT, "refdesignmatrix.txt"),
        (design2params._DESIGN_PARAMETERS_TXT, "refparameters_when_missing.txt"),
    ],
)
def test_run_with_no_parameters_txt(test_file, expected_file):
    design2params.run(
        1,
        "design_matrix.xlsx",
        "DesignSheet01",
        "DefaultValues",
        "new_parameters.txt",
        log_level=logging.DEBUG,
    )

    assert filecmp.cmp(test_file, expected_file)

    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
        status = status_file.read()
        assert status == "OK\n"


@pytest.mark.usefixtures("input_data")
@pytest.mark.parametrize(
    "test_file, expected_file",
    [
        (design2params._PARAMETERS_TXT, "refparameters_w_default.txt"),
        (design2params._DESIGN_MATRIX_TXT, "refdesignmatrix.txt"),
        (design2params._DESIGN_PARAMETERS_TXT, "refdesignparameters_w_default.txt"),
    ],
)
def test_run_with_default(test_file, expected_file):
    design2params.run(
        1,
        "design_matrix_tampered_defaults.xlsx",
        "DesignSheet01",
        "DefaultValues",
        design2params._PARAMETERS_TXT,
        log_level=logging.DEBUG,
    )

    assert filecmp.cmp(test_file, expected_file)

    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
        status = status_file.read()
        assert status == "OK\n"


@pytest.mark.usefixtures("input_data")
@pytest.mark.parametrize("realization_id", [(0), (1), (15), (24)])
def test_runs_different_reals_all_ok(realization_id):
    design2params.run(
        realization_id,
        "design_matrix_tampered_defaults.xlsx",
        "DesignSheet01",
        "DefaultValues",
        design2params._PARAMETERS_TXT,
        log_level=logging.DEBUG,
    )

    with open(design2params._TARGET_FILE_TXT, "r") as status_file:
        status = status_file.read()
        assert status == "OK\n"


def test_run_realization_not_exist(input_data):
    with pytest.raises(SystemExit):
        design2params.run(
            1000,
            "design_matrix.xlsx",
            "DesignSheet01",
            "DefaultValues",
            design2params._PARAMETERS_TXT,
            log_level=logging.DEBUG,
        )


def test_open_excel_file_not_existing(input_data):
    with pytest.raises(SystemExit):
        design2params._read_excel("not_existing.xlsx", "DesignSheet01")


def test_open_excel_file_not_xls(input_data):
    with pytest.raises(SystemExit):
        design2params._read_excel("parameters.txt", "DesignSheet01")


def test_open_excel_file_header_missing(input_data):
    with pytest.raises(SystemExit):
        design2params.run(
            1,
            "design_matrix_missing_header.xlsx",
            "DesignSheet01",
            "DefaultValues",
            design2params._PARAMETERS_TXT,
            log_level=logging.DEBUG,
        )


def test_open_excel_file_value_missing(input_data):
    with pytest.raises(SystemExit):
        design2params.run(
            1,
            "design_matrix_missing_value.xlsx",
            "DesignSheet01",
            "DefaultValues",
            design2params._PARAMETERS_TXT,
            log_level=logging.DEBUG,
        )



import numpy as np
import pandas as pd
import pytest

from ert_data import measured
from semeio.jobs.correlated_observations_scaling.job import ScalingJob
from semeio.jobs.correlated_observations_scaling.exceptions import ValidationError


def test_filter_on_column_index():
    matrix = np.random.rand(10, 10)

    index_lists = [[0, 1], [1, 2, 3], [1, 2, 3, 4, 5]]
    for index_list in index_lists:
        result = measured.MeasuredData._filter_on_column_index(
            pd.DataFrame(matrix), index_list
        )
        assert result.shape == (10, len(index_list))

    with pytest.raises(IndexError):
        measured.MeasuredData._filter_on_column_index(pd.DataFrame(matrix), [11])


@pytest.mark.parametrize(
    "calc_key,app_key,obs_keys,obs_with_data,expect_valid,errors",
    [
        ("KEY_1", "KEY_1", ["KEY_1"], ["KEY_1"], True, []),
        ("KEY_1", "KEY_1", ["KEY_1", "KEY_2"], ["KEY_1"], True, []),
        (
            "KEY_1",
            "KEY_1",
            ["KEY_1", "KEY_2"],
            ["KEY_2"],
            False,
            ["Key: KEY_1 has no data"],
        ),
        (
            "not_in_list",
            "KEY_1",
            ["KEY_1"],
            ["KEY_1"],
            False,
            [
                "Update key: KEY_1 missing from calculate keys: ['not_in_list']",
                "Key: not_in_list has no observations",
                "Key: not_in_list has no data",
            ],
        ),
        (
            "KEY_1",
            "not_in_list",
            ["KEY_1"],
            ["KEY_1"],
            False,
            ["Update key: not_in_list missing from calculate keys: ['KEY_1']"],
        ),
        ("KEY_1", "KEY_1", [], ["KEY_1"], False, ["Key: KEY_1 has no observations"]),
        ("KEY_1", "KEY_1", ["KEY_1"], [], False, ["Key: KEY_1 has no data"]),
    ],
)
@pytest.mark.usefixtures("setup_tmpdir")
def test_valid_job(calc_key, app_key, obs_keys, obs_with_data, expect_valid, errors):
    user_config_dict = {
        "CALCULATE_KEYS": {"keys": [{"key": calc_key}]},
        "UPDATE_KEYS": {"keys": [{"key": app_key}]},
    }
    if expect_valid:
        try:
            ScalingJob(obs_keys, [], obs_with_data, user_config_dict)
        except ValidationError as e:
            pytest.fail("unexpectedly raised ValidationError: {}".format(e))
    else:
        with pytest.raises(ValidationError) as exc_info:
            ScalingJob(obs_keys, [], obs_with_data, user_config_dict)
        assert exc_info.value.errors == errors



import json
import logging
import os
import re
import string
import sys

_STATUS_FILE_NAME = "DESIGN_KW.OK"

_logger = logging.getLogger(__name__)


def run(
    template_file_name,
    result_file_name,
    log_level,
    parameters_file_name="parameters.txt",
):
    # Get all key, value pairs
    # If FWL key is having multiple entries in the parameters file
    # KeyError is raised. This will be logged, and no OK
    # file is written

    _logger.setLevel(log_level)

    valid = True
    with open(parameters_file_name) as parameters_file:
        parameters = parameters_file.readlines()

    key_vals = extract_key_value(parameters)

    with open(template_file_name, "r") as template_file:
        template = template_file.readlines()

    if valid:
        with open(result_file_name, "w") as result_file:
            for line in template:
                if not is_comment(line):
                    for key, value in key_vals.items():
                        line = line.replace("<{}>".format(key), str(value))

                    if not all_matched(line, template_file_name, template):
                        valid = False

                result_file.write(line)

    if valid:
        with open(_STATUS_FILE_NAME, "w") as status_file:
            status_file.write("DESIGN_KW OK\n")


def all_matched(line, template_file_name, template):
    valid = True
    for unmatched in unmatched_templates(line):
        if is_perl(template_file_name, template):
            _logger.warn(
                "{} not found in design matrix, but this is probably a Perl file".format(
                    unmatched
                )
            )
        else:
            _logger.error("{} not found in design matrix".format(unmatched))
            valid = False
    return valid


def is_perl(file_name, template):
    return file_name.endswith(".pl") or template[0].find("perl") != -1


def unmatched_templates(line):
    bracketpattern = re.compile("<.+?>")
    if bracketpattern.search(line):
        return bracketpattern.findall(line)
    else:
        return []


def is_comment(line):
    ecl_comment_pattern = re.compile("^--")
    std_comment_pattern = re.compile("^#")
    return ecl_comment_pattern.search(line) or std_comment_pattern.search(line)


def extract_key_value(parameters):
    # Extract all key, value pairs from parameters file
    # If key already exists, raise Exception

    res = {}
    for line in parameters:
        key, value = line.split()
        if key in res:
            raise SystemExit(
                "{} is defined multiple times in parameters file".format(key)
            )
        res[key] = value
    return res



import argparse
import os

from semeio.jobs.rft.utility import strip_comments


class TrajectoryPoint:
    def __init__(self, utm_x, utm_y, measured_depth, true_vertical_depth, zone=None):
        self.utm_x = utm_x
        self.utm_y = utm_y
        self.measured_depth = measured_depth
        self.true_vertical_depth = true_vertical_depth
        self.zone = zone
        self.grid_ijk = None
        self.pressure = None
        self.valid_zone = False

    def set_ijk(self, point):
        self.grid_ijk = point

    def validate_zone(self, zonemap=None):
        if self.zone is None:
            self.valid_zone = True
        elif self.grid_ijk:
            self.valid_zone = zonemap is None or zonemap.has_relationship(
                self.zone, self.grid_ijk[2]
            )

    def is_active(self):
        return (
            self.grid_ijk is not None and self.pressure is not None and self.valid_zone
        )

    def inactive_info(self, zonemap=None):
        if self.grid_ijk is None:
            return "TRAJECTORY_POINT_NOT_IN_GRID {}".format(str(self))
        if self.pressure is None:
            return "TRAJECTORY_POINT_NOT_IN_RFT {}".format(str(self))
        if not self.valid_zone and zonemap is not None:
            if self.grid_ijk[2] not in zonemap:
                return "ZONEMAP_MISSING_VALUE {} {} {}".format(
                    str(self), self.grid_ijk[2], None
                )

            return "ZONE_MISMATCH {} {} {}".format(
                str(self), self.grid_ijk[2], zonemap[self.grid_ijk[2]]
            )

    def get_pressure(self):
        if self.is_active():
            return self.pressure
        return -1

    def update_pressure_from_rft(self, rft):
        if self.grid_ijk:
            rftcell = rft.ijkget(self.grid_ijk)
            if rftcell:
                self.pressure = rftcell.pressure


class Trajectory:
    def __init__(self, points):
        self.trajectory_points = [TrajectoryPoint(*point) for point in points]

    def __getitem__(self, i):
        return self.trajectory_points[i]

    def __len__(self):
        return len(self.trajectory_points)

    @staticmethod
    def parse_trajectory_line(line):
        point = line.split()
        if len(point) < 4 or len(point) > 5:
            raise argparse.ArgumentTypeError(
                "Trajectory data file not on correct format: 'utm_x utm_y md tvd <zone>' - zone is optional"
            )

        try:
            floats = [float(v) for v in point[:4]]
        except ValueError:
            raise argparse.ArgumentTypeError(
                "Error: Failed to extract data from line {line}".format(line=line)
            )

        zone = point[4].strip() if len(point) == 5 else None
        return floats + [zone]

    @classmethod
    def load_from_file(cls, filepath):

        trajectory_points = []

        filename = os.path.join(filepath)
        if not os.path.isfile(filename):
            raise argparse.ArgumentTypeError(
                "Warning: Trajectory file {filename} not found!".format(
                    filename=filename
                )
            )

        with open(filename, "r") as f:
            trajectory_lines = f.readlines()

        trajectory_lines = [strip_comments(l) for l in trajectory_lines]

        for line in trajectory_lines:
            if not line:
                continue
            point = Trajectory.parse_trajectory_line(line)
            trajectory_points.append(point)

        return cls(trajectory_points)



import os
from pkg_resources import resource_filename

from ert_shared.plugins.plugin_manager import hook_implementation
from ert_shared.plugins.plugin_response import plugin_response


def _get_jobs_from_directory(directory):
    resource_directory = resource_filename("semeio", directory)

    all_files = [
        os.path.join(resource_directory, f)
        for f in os.listdir(resource_directory)
        if os.path.isfile(os.path.join(resource_directory, f))
    ]
    return {os.path.basename(path): path for path in all_files}


@hook_implementation
@plugin_response(plugin_name="semeio")
def installable_jobs():
    return _get_jobs_from_directory("jobs/config_jobs")


@hook_implementation
@plugin_response(plugin_name="semeio")
def installable_workflow_jobs():
    return _get_jobs_from_directory("jobs/config_workflow_jobs")



#!/usr/bin/env python

import argparse
import logging
import os
import sys

from semeio import valid_file
from semeio.jobs.design_kw import design_kw

description = """
Performs text->value substitutions (similar to GEN_KW in ERT)
in template files, picking values from parameters.txt.
This is designed for using in conjunction with a "Design matrix", but
this particular script only requires key-values to exist in parameters.txt
Therefore, you should run the designmatrix-to-parameters job ahead of the
DESIGN_KW jobs (FORWARD_MODELs).
Fails hard if resultFile contains unmatched template directives after substitutions
on non-comment lines (assuming comments start with "--" or "#", at beginning of line only)
"""


def create_parser():
    parser = argparse.ArgumentParser(description=description)

    parser.add_argument(
        "templatefile", type=valid_file, help="Path to template-file",
    )

    parser.add_argument(
        "resultfile", type=str, help="Path to result-file",
    )

    parser.add_argument(
        "--log-level", required=False, default="WARNING", type=logging.getLevelName,
    )

    return parser


def main(args):
    parser = create_parser()
    parsed_args = parser.parse_args(args)

    design_kw.run(
        template_file_name=parsed_args.templatefile,
        result_file_name=parsed_args.resultfile,
        log_level=parsed_args.log_level,
    )


if __name__ == "__main__":
    main(sys.argv[1:])
